@@ -162,12 +162,7 @@ class TokenAuthHttpDownloader(HttpDownloader):
             }
             url = self.ansible_auth_url
             async with self.session.post(
-                url,
-                data=form_payload,
-                proxy=self.proxy,
-                proxy_auth=self.proxy_auth,
-                auth=self.auth,
-                raise_for_status=True,
+                url, data=form_payload, proxy=self.proxy, raise_for_status=True
             ) as response:
                 token_data = await response.text()
 
@@ -216,10 +211,6 @@ class AnsibleDownloaderFactory(DownloaderFactory):
         options = {"session": self._session}
         if self._remote.proxy_url:
             options["proxy"] = self._remote.proxy_url
-            if self._remote.proxy_username and self._remote.proxy_password:
-                options["proxy_auth"] = BasicAuth(
-                    login=self._remote.proxy_username, password=self._remote.proxy_password
-                )
 
         if not self._remote.token and self._remote.username and self._remote.password:
             options["auth"] = BasicAuth(login=self._remote.username, password=self._remote.password)
